@@ -19,12 +19,8 @@
 #define _ASTERISK_H
 
 #include "asterisk/autoconfig.h"
-
-#if !defined(NO_MALLOC_DEBUG) && !defined(STANDALONE) && !defined(STANDALONE2) && defined(MALLOC_DEBUG)
-#include "asterisk/astmm.h"
-#endif
-
 #include "asterisk/compat.h"
+#include "asterisk/astmm.h"
 
 /* Default to allowing the umask or filesystem ACLs to determine actual file
  * creation permissions
@@ -45,6 +41,8 @@
 #endif
 
 
+#define AST_CURL_USER_AGENT "asterisk-libcurl-agent/1.0"
+
 #define DEFAULT_LANGUAGE "en"
 
 #define DEFAULT_SAMPLE_RATE 8000
@@ -54,15 +52,15 @@
 
 #if defined(DEBUG_FD_LEAKS) && !defined(STANDALONE) && !defined(STANDALONE2) && !defined(STANDALONE_AEL)
 /* These includes are all about ordering */
-#include <stdio.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
 #include <fcntl.h>
 
 #define	open(a,...)	__ast_fdleak_open(__FILE__,__LINE__,__PRETTY_FUNCTION__, a, __VA_ARGS__)
 #define pipe(a)		__ast_fdleak_pipe(a, __FILE__,__LINE__,__PRETTY_FUNCTION__)
+#define socketpair(a,b,c,d)	__ast_fdleak_socketpair(a, b, c, d, __FILE__,__LINE__,__PRETTY_FUNCTION__)
 #define socket(a,b,c)	__ast_fdleak_socket(a, b, c, __FILE__,__LINE__,__PRETTY_FUNCTION__)
+#define accept(a,b,c)	__ast_fdleak_accept(a, b, c, __FILE__,__LINE__,__PRETTY_FUNCTION__)
 #define close(a)	__ast_fdleak_close(a)
 #define	fopen(a,b)	__ast_fdleak_fopen(a, b, __FILE__,__LINE__,__PRETTY_FUNCTION__)
 #define	fclose(a)	__ast_fdleak_fclose(a)
@@ -74,7 +72,21 @@ extern "C" {
 #endif
 int __ast_fdleak_open(const char *file, int line, const char *func, const char *path, int flags, ...);
 int __ast_fdleak_pipe(int *fds, const char *file, int line, const char *func);
+int __ast_fdleak_socketpair(int domain, int type, int protocol, int sv[2],
+	const char *file, int line, const char *func);
 int __ast_fdleak_socket(int domain, int type, int protocol, const char *file, int line, const char *func);
+int __ast_fdleak_accept(int socket, struct sockaddr *address, socklen_t *address_len,
+	const char *file, int line, const char *func);
+#if defined(HAVE_EVENTFD)
+#include <sys/eventfd.h>
+#define eventfd(a,b)	__ast_fdleak_eventfd(a,b, __FILE__,__LINE__,__PRETTY_FUNCTION__)
+int __ast_fdleak_eventfd(unsigned int initval, int flags, const char *file, int line, const char *func);
+#endif
+#if defined(HAVE_TIMERFD)
+#include <sys/timerfd.h>
+#define timerfd_create(a,b)	__ast_fdleak_timerfd_create(a,b, __FILE__,__LINE__,__PRETTY_FUNCTION__)
+int __ast_fdleak_timerfd_create(int clockid, int flags, const char *file, int line, const char *func);
+#endif
 int __ast_fdleak_close(int fd);
 FILE *__ast_fdleak_fopen(const char *path, const char *mode, const char *file, int line, const char *func);
 int __ast_fdleak_fclose(FILE *ptr);
@@ -161,126 +173,10 @@ int ast_shutting_down(void);
  */
 int ast_shutdown_final(void);
 
-#if !defined(LOW_MEMORY)
-/*!
- * \brief Register the version of a source code file with the core.
- * \param file the source file name
- * \param version the version string (typically a SVN revision keyword string)
- * \return nothing
- *
- * \note As of 13.4.0, the \c version parameter is ignored.
- *
- * This function should not be called directly, but instead the
- * ASTERISK_FILE_VERSION macro should be used to register a file with the core.
- */
-void ast_register_file_version(const char *file, const char *version);
-
-/*!
- * \brief Unregister a source code file from the core.
- * \param file the source file name
- * \return nothing
- *
- * This function should not be called directly, but instead the
- * ASTERISK_FILE_VERSION macro should be used to automatically unregister
- * the file when the module is unloaded.
- */
-void ast_unregister_file_version(const char *file);
-
-/*!
- * \brief Find version for given module name
- * \param file Module name (i.e. chan_sip.so)
- *
-* \note As of 13.4.0, the file version is no longer tracked. As such,
- * if the file exists, the Asterisk version will be returned.
- *
- * \retval NULL if the file doesn't exist.
- * \retval The Asterisk version if the file does exist.
- */
-const char *ast_file_version_find(const char *file);
-
-/*!
- * \brief Complete a source file name
- * \param partial The partial name of the file to look up.
- * \param n The n-th match to return.
- *
- * \retval NULL if there is no match for partial at the n-th position
- * \retval Matching source file name
- *
- * \note A matching source file is allocataed on the heap, and must be
- * free'd by the caller.
- */
-char *ast_complete_source_filename(const char *partial, int n);
-
-/*!
- * \brief Register/unregister a source code file with the core.
- * \param file the source file name
- * \param version the version string (typically a SVN revision keyword string)
- *
- * This macro will place a file-scope constructor and destructor into the
- * source of the module using it; this will cause the version of this file
- * to registered with the Asterisk core (and unregistered) at the appropriate
- * times.
- *
- * Example:
- *
- * \code
- * ASTERISK_FILE_VERSION(__FILE__, "\$Revision\$")
- * \endcode
- *
- * \note The dollar signs above have been protected with backslashes to keep
- * SVN from modifying them in this file; under normal circumstances they would
- * not be present and SVN would expand the Revision keyword into the file's
- * revision number.
- *
- * \deprecated All new files should use ASTERISK_REGISTER_FILE instead.
- * \version 11.22.0 deprecated
- */
 #ifdef MTX_PROFILE
 #define	HAVE_MTX_PROFILE	/* used in lock.h */
-#define ASTERISK_FILE_VERSION(file, version) \
-	static int mtx_prof = -1;       /* profile mutex */	\
-	static void __attribute__((constructor)) __register_file_version(void) \
-	{ \
-		mtx_prof = ast_add_profile("mtx_lock_" file, 0);	\
-		ast_register_file_version(file, version); \
-	} \
-	static void __attribute__((destructor)) __unregister_file_version(void) \
-	{ \
-		ast_unregister_file_version(file); \
-	}
-#else /* !MTX_PROFILE */
-#define ASTERISK_FILE_VERSION(file, version) \
-	static void __attribute__((constructor)) __register_file_version(void) \
-	{ \
-		ast_register_file_version(file, version); \
-	} \
-	static void __attribute__((destructor)) __unregister_file_version(void) \
-	{ \
-		ast_unregister_file_version(file); \
-	}
-#endif /* !MTX_PROFILE */
-#else /* LOW_MEMORY */
-#define ASTERISK_FILE_VERSION(file, x)
-#endif /* LOW_MEMORY */
+#endif /* MTX_PROFILE */
 
-/*!
- * \since 11.22.0
- * \brief Register/unregister a source code file with the core.
- *
- * This macro will place a file-scope constructor and destructor into the
- * source of the module using it; this will cause the file to be
- * registered with the Asterisk core (and unregistered) at the appropriate
- * times.
- *
- * Example:
- *
- * \code
- * ASTERISK_REGISTER_FILE()
- * \endcode
- */
-#define ASTERISK_REGISTER_FILE() ASTERISK_FILE_VERSION(__FILE__, NULL)
-
-#if !defined(LOW_MEMORY)
 /*!
  * \brief support for event profiling
  *
@@ -299,11 +195,6 @@ char *ast_complete_source_filename(const char *partial, int n);
 int ast_add_profile(const char *, uint64_t scale);
 int64_t ast_profile(int, int64_t);
 int64_t ast_mark(int, int start1_stop0);
-#else /* LOW_MEMORY */
-#define ast_add_profile(a, b) 0
-#define ast_profile(a, b) do { } while (0)
-#define ast_mark(a, b) do { } while (0)
-#endif /* LOW_MEMORY */
 
 /*! \brief
  * Definition of various structures that many asterisk files need,
@@ -317,11 +208,33 @@ struct ast_module;
 struct ast_variable;
 struct ast_str;
 struct ast_sched_context;
+struct ast_json;
 
 /* Some handy macros for turning a preprocessor token into (effectively) a quoted string */
 #define __stringify_1(x)	#x
 #define __stringify(x)		__stringify_1(x)
 
+#if defined(AST_IN_CORE) \
+	|| (!defined(AST_MODULE_SELF_SYM) \
+		&& (defined(STANDALONE) || defined(STANDALONE2) || defined(AST_NOT_MODULE)))
+
+#define AST_MODULE_SELF NULL
+
+#elif defined(AST_MODULE_SELF_SYM)
+
+/*! Retrieve the 'struct ast_module *' for the current module. */
+#define AST_MODULE_SELF AST_MODULE_SELF_SYM()
+
+struct ast_module;
+/* Internal/forward declaration, AST_MODULE_SELF should be used instead. */
+struct ast_module *AST_MODULE_SELF_SYM(void);
+
+#else
+
+#error "Externally compiled modules must declare AST_MODULE_SELF_SYM."
+
+#endif
+
 /*!
  * \brief Retrieve the PBX UUID
  * \param pbx_uuid A buffer of at least AST_UUID_STR_LEN (36 + 1) size to receive the UUID
