@@ -30,29 +30,31 @@ extern "C" {
 #include "asterisk/optional_api.h"
 #include "asterisk/logger.h"
 
-#ifdef HAVE_CRYPTO
-#include "openssl/aes.h"
-typedef AES_KEY ast_aes_encrypt_key;
-typedef AES_KEY ast_aes_decrypt_key;
-#else /* !HAVE_CRYPTO */
-typedef char ast_aes_encrypt_key;
-typedef char ast_aes_decrypt_key;
-#endif /* HAVE_CRYPTO */
+/* We previously used the key length explicitly; replace with constant.
+ * For now, Asterisk is limited to 1024 bit (128 byte) RSA keys.
+ */
+#define AST_CRYPTO_RSA_KEY_BITS		1024
+#define AST_CRYPTO_AES_BLOCKSIZE	128
+
+struct aes_key {
+	unsigned char raw[AST_CRYPTO_AES_BLOCKSIZE / 8];
+};
+
+typedef struct aes_key ast_aes_encrypt_key;
+typedef struct aes_key ast_aes_decrypt_key;
 
 #define AST_KEY_PUBLIC	(1 << 0)
 #define AST_KEY_PRIVATE	(1 << 1)
 
-struct ast_key;
-
 /*!
  * \brief Retrieve a key
- * \param key Name of the key we are retrieving
- * \param type Intger type of key (AST_KEY_PUBLIC or AST_KEY_PRIVATE)
+ * \param kname Name of the key we are retrieving
+ * \param ktype Intger type of key (AST_KEY_PUBLIC or AST_KEY_PRIVATE)
  *
  * \retval the key on success.
  * \retval NULL on failure.
  */
-AST_OPTIONAL_API(struct ast_key *, ast_key_get, (const char *key, int type), { return NULL; });
+AST_OPTIONAL_API(struct ast_key *, ast_key_get, (const char *kname, int ktype), { return NULL; });
 
 /*!
  * \brief Check the authenticity of a message signature using a given public key
@@ -71,13 +73,13 @@ AST_OPTIONAL_API(int, ast_check_signature, (struct ast_key *key, const char *msg
  * \param key a public key to use to verify
  * \param msg the message that has been signed
  * \param msglen
- * \param sig the proposed valid signature in raw binary representation
+ * \param dsig the proposed valid signature in raw binary representation
  *
  * \retval 0 if the signature is valid.
  * \retval -1 otherwise.
  *
  */
-AST_OPTIONAL_API(int, ast_check_signature_bin, (struct ast_key *key, const char *msg, int msglen, const unsigned char *sig), { return -1; });
+AST_OPTIONAL_API(int, ast_check_signature_bin, (struct ast_key *key, const char *msg, int msglen, const unsigned char *dsig), { return -1; });
 
 /*!
  * \brief Sign a message signature using a given private key
@@ -97,14 +99,14 @@ AST_OPTIONAL_API(int, ast_sign, (struct ast_key *key, char *msg, char *sig), { r
  * \param key a private key to use to create the signature
  * \param msg the message to sign
  * \param msglen
- * \param sig a pointer to a buffer of at least 128 bytes in which the
+ * \param dsig a pointer to a buffer of at least 128 bytes in which the
  * raw encoded signature will be stored
  *
  * \retval 0 on success.
  * \retval -1 on failure.
  *
  */
-AST_OPTIONAL_API(int, ast_sign_bin, (struct ast_key *key, const char *msg, int msglen, unsigned char *sig), { return -1; });
+AST_OPTIONAL_API(int, ast_sign_bin, (struct ast_key *key, const char *msg, int msglen, unsigned char *dsig), { return -1; });
 
 /*!
  * \brief Encrypt a message using a given private key
@@ -128,7 +130,7 @@ AST_OPTIONAL_API(int, ast_encrypt_bin, (unsigned char *dst, const unsigned char
  * \param dst a pointer to a buffer of at least srclen bytes in which the decrypted
  * answer will be stored
  *
- * \retval length of dencrypted data on success.
+ * \retval length of decrypted data on success.
  * \retval -1 on failure.
  *
  */
@@ -163,23 +165,29 @@ AST_OPTIONAL_API(int, ast_aes_set_decrypt_key,
  * \param in data to be encrypted
  * \param out pointer to a buffer to hold the encrypted output
  * \param ctx address of an aes encryption context filled in with ast_aes_set_encrypt_key
+ * \retval <= 0 failure
+ * \retval otherwise number of bytes in output buffer
  */
-AST_OPTIONAL_API(void, ast_aes_encrypt,
-	(const unsigned char *in, unsigned char *out, const ast_aes_encrypt_key *ctx),
-	{ ast_log(LOG_WARNING, "AES encryption disabled. Install OpenSSL.\n");return; });
+AST_OPTIONAL_API(int, ast_aes_encrypt,
+	(const unsigned char *in, unsigned char *out, const ast_aes_encrypt_key *key),
+	{ ast_log(LOG_WARNING, "AES encryption disabled. Install OpenSSL.\n");return -1; });
 
 /*!
  * \brief AES decrypt data
  * \param in encrypted data
  * \param out pointer to a buffer to hold the decrypted output
  * \param ctx address of an aes encryption context filled in with ast_aes_set_decrypt_key
+ * \retval <= 0 failure
+ * \retval otherwise number of bytes in output buffer
  */
-AST_OPTIONAL_API(void, ast_aes_decrypt,
-	(const unsigned char *in, unsigned char *out, const ast_aes_decrypt_key *ctx),
-	{ ast_log(LOG_WARNING, "AES encryption disabled. Install OpenSSL.\n");return; });
+AST_OPTIONAL_API(int, ast_aes_decrypt,
+	(const unsigned char *in, unsigned char *out, const ast_aes_decrypt_key *key),
+	{ ast_log(LOG_WARNING, "AES encryption disabled. Install OpenSSL.\n");return -1; });
 
 AST_OPTIONAL_API(int, ast_crypto_loaded, (void), { return 0; });
 
+AST_OPTIONAL_API(int, ast_crypto_reload, (void), { return 0; });
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
