@@ -16,9 +16,11 @@
  * at the top of the source tree.
  */
 
-/*!	\file enum.h
-	\brief DNS and ENUM functions
-*/
+/*!
+ * \file
+ *
+ * \brief DNS and ENUM functions
+ */
 
 #ifndef _ASTERISK_ENUM_H
 #define _ASTERISK_ENUM_H
@@ -97,7 +99,4 @@ int ast_get_enum(struct ast_channel *chan, const char *number, char *location, i
  */
 int ast_get_txt(struct ast_channel *chan, const char *number, char *txt, int maxtxt, char *suffix);
 
-int ast_enum_init(void);
-int ast_enum_reload(void);
-
 #endif /* _ASTERISK_ENUM_H */
