@@ -27,7 +27,7 @@
  * \since 12.0.0
  *
  * This is a very thin wrapper around the Jansson API. For more details on it,
- * see its docs at http://www.digip.org/jansson/doc/2.4/apiref.html.
+ * see its docs at http://www.digip.org/jansson/doc/2.11/apiref.html.
  *
  * Rather than provide the multiple ways of doing things that the Jansson API
  * does, the Asterisk wrapper is always reference-stealing, and always NULL
@@ -43,35 +43,6 @@
  * wrap them with json_ref() when passing them to other \c ast_json_*()
  * functions.
  *
- * \par Thread Safety
- *
- * Jansson (as of 2.4) provides fairly weak thread safety guarantees. The
- * Asterisk wrapper improves upon that slightly. The remaining refcounting
- * problems are issues when slicing/sharing/mixing instances between JSON
- * objects and arrays, which we avoid.
- *
- * The \c ast_json_dump_* functions are thread safe for multiple concurrent
- * dumps of the same object, so long as the concurrent dumps start from the same
- * \c root object. But if an object is shared by other JSON objects/arrays, then
- * concurrent dumps of the outer objects/arrays are not thread safe. This can be
- * avoided by using ast_json_deep_copy() when sharing JSON instances between
- * objects.
- *
- * The ast_json_ref() and ast_json_unref() functions are thread safe. Since the
- * Asterisk wrapper exclusively uses the reference stealing API, Jansson won't
- * be performing many refcount modifications behind our backs. There are a few
- * exceptions.
- *
- * The first is the transitive json_decref() that occurs when \ref
- * AST_JSON_OBJECT and \ref AST_JSON_ARRAY instances are deleted. This can be
- * avoided by using ast_json_deep_copy() when sharing JSON instances between
- * objects.
- *
- * The second is when using the reference borrowing specifier in
- * ast_json_pack() (capital \c O). This can be avoided by using the reference
- * stealing specifier (lowercase \c o) and wrapping the JSON object parameter
- * with ast_json_ref() for an explicit ref-bump.
- *
  * \par Example code
  *
  * \code
@@ -110,10 +81,15 @@
 
 /*!@{*/
 
+/*!
+ * \brief Primarily used to cast when packing to an "I" type.
+ */
+typedef AST_JSON_INT_T ast_json_int_t;
+
 /*!
  * \brief Initialize the JSON library.
  */
-void ast_json_init(void);
+int ast_json_init(void);
 
 /*!
  * \brief Set custom allocators instead of the standard ast_malloc() and ast_free().
@@ -208,7 +184,7 @@ enum ast_json_type ast_json_typeof(const struct ast_json *value);
  * \since 12.0.0
  * \param type Type to convert to string.
  * \return Simple string for the type name (object, array, string, etc.)
- * \return \c "?" for invalid types.
+ * \retval "?" for invalid types.
  */
 const char *ast_json_typename(enum ast_json_type type);
 
@@ -295,24 +271,24 @@ struct ast_json *ast_json_null(void);
 /*!
  * \brief Check if \a value is JSON true.
  * \since 12.0.0
- * \return True (non-zero) if \a value == \ref ast_json_true().
- * \return False (zero) otherwise..
+ * \retval True (non-zero) if \a value == \ref ast_json_true().
+ * \retval False (zero) otherwise..
  */
 int ast_json_is_true(const struct ast_json *value);
 
 /*!
  * \brief Check if \a value is JSON false.
  * \since 12.0.0
- * \return True (non-zero) if \a value == \ref ast_json_false().
- * \return False (zero) otherwise.
+ * \retval True (non-zero) if \a value == \ref ast_json_false().
+ * \retval False (zero) otherwise.
  */
 int ast_json_is_false(const struct ast_json *value);
 
 /*!
  * \brief Check if \a value is JSON null.
  * \since 12.0.0
- * \return True (non-zero) if \a value == \ref ast_json_false().
- * \return False (zero) otherwise.
+ * \retval True (non-zero) if \a value == \ref ast_json_false().
+ * \retval False (zero) otherwise.
  */
 int ast_json_is_null(const struct ast_json *value);
 
@@ -328,7 +304,7 @@ int ast_json_is_null(const struct ast_json *value);
  *
  * \param value Value of new JSON string.
  * \return Newly constructed string element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_string_create(const char *value);
 
@@ -337,7 +313,7 @@ struct ast_json *ast_json_string_create(const char *value);
  * \since 12.0.0
  * \param string JSON string.
  * \return Value of the string.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 const char *ast_json_string_get(const struct ast_json *string);
 
@@ -349,8 +325,8 @@ const char *ast_json_string_get(const struct ast_json *string);
  *
  * \param string JSON string to modify.
  * \param value New value to store in \a string.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_string_set(struct ast_json *string, const char *value);
 
@@ -362,7 +338,7 @@ int ast_json_string_set(struct ast_json *string, const char *value);
  *
  * \param format \c printf style format string.
  * \return Newly allocated string.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_stringf(const char *format, ...) __attribute__((format(printf, 1, 2)));
 
@@ -373,8 +349,10 @@ struct ast_json *ast_json_stringf(const char *format, ...) __attribute__((format
  * The formatted value must be a valid ASCII or UTF-8 encoded string.
  *
  * \param format \c printf style format string.
+ * \param args
+ *
  * \return Newly allocated string.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_vstringf(const char *format, va_list args) __attribute__((format(printf, 1, 0)));
 
@@ -387,7 +365,7 @@ struct ast_json *ast_json_vstringf(const char *format, va_list args) __attribute
  * \since 12.0.0
  * \param value Value of the new JSON integer.
  * \return Newly allocated integer.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_integer_create(intmax_t value);
 
@@ -396,7 +374,7 @@ struct ast_json *ast_json_integer_create(intmax_t value);
  * \since 12.0.0
  * \param integer JSON integer.
  * \return Value of a JSON integer.
- * \return 0 if \a integer is not a JSON integer.
+ * \retval 0 if \a integer is not a JSON integer.
  */
 intmax_t ast_json_integer_get(const struct ast_json *integer);
 
@@ -405,8 +383,8 @@ intmax_t ast_json_integer_get(const struct ast_json *integer);
  * \since 12.0.0
  * \param integer JSON integer to modify.
  * \param value New value for \a integer.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_integer_set(struct ast_json *integer, intmax_t value);
 
@@ -415,7 +393,7 @@ int ast_json_integer_set(struct ast_json *integer, intmax_t value);
  * \since 12.0.0
  * \param value Value of the new JSON real number.
  * \return Newly allocated real number.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_real_create(double value);
 
@@ -424,17 +402,17 @@ struct ast_json *ast_json_real_create(double value);
  * \since 12.0.0
  * \param real JSON real number.
  * \return Value of a JSON real number.
- * \return 0 if \a real is not a JSON real number.
+ * \retval 0 if \a real is not a JSON real number.
  */
 double ast_json_real_get(const struct ast_json *real);
 
 /*!
  * \brief Set the value of a JSON real number.
  * \since 12.0.0
- * \param integer JSON real number to modify.
+ * \param real JSON real number to modify.
  * \param value New value for \a real.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_real_set(struct ast_json *real, double value);
 
@@ -446,7 +424,7 @@ int ast_json_real_set(struct ast_json *real, double value);
  * \brief Create a empty JSON array.
  * \since 12.0.0
  * \return Newly allocated array.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_array_create(void);
 
@@ -455,7 +433,7 @@ struct ast_json *ast_json_array_create(void);
  * \since 12.0.0
  * \param array JSON array.
  * \return Size of \a array.
- * \return 0 if array is not a JSON array.
+ * \retval 0 if array is not a JSON array.
  */
 size_t ast_json_array_size(const struct ast_json *array);
 
@@ -469,8 +447,8 @@ size_t ast_json_array_size(const struct ast_json *array);
  * \param array JSON array.
  * \param index Zero-based index into \a array.
  * \return The specified element.
- * \return \c NULL if \a array not an array.
- * \return \c NULL if \a index is out of bounds.
+ * \retval NULL if \a array not an array.
+ *              if \a index is out of bounds.
  */
 struct ast_json *ast_json_array_get(const struct ast_json *array, size_t index);
 
@@ -484,8 +462,8 @@ struct ast_json *ast_json_array_get(const struct ast_json *array, size_t index);
  * \param array JSON array to modify.
  * \param index Zero-based index into array.
  * \param value New JSON value to store in \a array at \a index.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_set(struct ast_json *array, size_t index, struct ast_json *value);
 
@@ -498,8 +476,8 @@ int ast_json_array_set(struct ast_json *array, size_t index, struct ast_json *va
  *
  * \param array JSON array to modify.
  * \param value New JSON value to store at the end of \a array.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_append(struct ast_json *array, struct ast_json *value);
 
@@ -513,8 +491,8 @@ int ast_json_array_append(struct ast_json *array, struct ast_json *value);
  * \param array JSON array to modify.
  * \param index Zero-based index into array.
  * \param value New JSON value to store in \a array at \a index.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_insert(struct ast_json *array, size_t index, struct ast_json *value);
 
@@ -523,8 +501,8 @@ int ast_json_array_insert(struct ast_json *array, size_t index, struct ast_json
  * \since 12.0.0
  * \param array JSON array to modify.
  * \param index Zero-based index into array.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_remove(struct ast_json *array, size_t index);
 
@@ -532,8 +510,8 @@ int ast_json_array_remove(struct ast_json *array, size_t index);
  * \brief Remove all elements from an array.
  * \since 12.0.0
  * \param array JSON array to clear.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_clear(struct ast_json *array);
 
@@ -545,8 +523,8 @@ int ast_json_array_clear(struct ast_json *array);
  *
  * \param array JSON array to modify.
  * \param tail JSON array with contents to append to \a array.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_array_extend(struct ast_json *array, struct ast_json *tail);
 
@@ -558,16 +536,25 @@ int ast_json_array_extend(struct ast_json *array, struct ast_json *tail);
  * \brief Create a new JSON object.
  * \since 12.0.0
  * \return Newly allocated object.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_object_create(void);
 
+/*!
+ * \brief Create a new JSON object using the given variables
+ * \param variables A list of Asterisk variables
+ * \param excludes Comma separated string of variable names to exclude (optional)
+ * \return Newly allocated object.
+ * \retval NULL on error.
+ */
+struct ast_json *ast_json_object_create_vars(const struct ast_variable *variables, const char *excludes);
+
 /*!
  * \brief Get size of JSON object.
  * \since 12.0.0
  * \param object JSON object.
  * \return Size of \a object.
- * \return Zero of \a object is not a JSON object.
+ * \retval Zero of \a object is not a JSON object.
  */
 size_t ast_json_object_size(struct ast_json *object);
 
@@ -581,10 +568,30 @@ size_t ast_json_object_size(struct ast_json *object);
  * \param object JSON object.
  * \param key Key of field to look up.
  * \return Value with given \a key.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_object_get(struct ast_json *object, const char *key);
 
+/*!
+ * \brief Get a string field from a JSON object.
+ * \since 16.3.0
+ *
+ * \param object JSON object.
+ * \param key Key of string field to look up.
+ * \return String value of given \a key.
+ * \retval NULL on error, or key value is not a string.
+ */
+#define ast_json_object_string_get(object, key) ast_json_string_get(ast_json_object_get(object, key))
+
+/*!
+ * \brief Get an integer field from a JSON object.
+ * \param object JSON object.
+ * \param key Key of integer field to look up.
+ * \return Value of a JSON integer.
+ * \retval 0 if \a integer is not a JSON integer.
+ */
+#define ast_json_object_integer_get(object, key) ast_json_integer_get(ast_json_object_get(object, key))
+
 /*!
  * \brief Set a field in a JSON object.
  * \since 12.0.0
@@ -595,8 +602,8 @@ struct ast_json *ast_json_object_get(struct ast_json *object, const char *key);
  * \param object JSON object to modify.
  * \param key Key of field to set.
  * \param value JSON value to set for field.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_set(struct ast_json *object, const char *key, struct ast_json *value);
 
@@ -606,7 +613,7 @@ int ast_json_object_set(struct ast_json *object, const char *key, struct ast_jso
  *
  * \param object JSON object to modify.
  * \param key Key of field to delete.
- * \return 0 on success, or -1 if key does not exist.
+ * \retval 0 on success, or -1 if key does not exist.
  */
 int ast_json_object_del(struct ast_json *object, const char *key);
 
@@ -614,8 +621,8 @@ int ast_json_object_del(struct ast_json *object, const char *key);
  * \brief Delete all elements from a JSON object.
  * \since 12.0.0
  * \param object JSON object to clear.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_clear(struct ast_json *object);
 
@@ -628,8 +635,8 @@ int ast_json_object_clear(struct ast_json *object);
  *
  * \param object JSON object to modify.
  * \param other JSON object to copy into \a object.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_update(struct ast_json *object, struct ast_json *other);
 
@@ -643,8 +650,8 @@ int ast_json_object_update(struct ast_json *object, struct ast_json *other);
  *
  * \param object JSON object to modify.
  * \param other JSON object to copy into \a object.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_update_existing(struct ast_json *object, struct ast_json *other);
 
@@ -658,8 +665,8 @@ int ast_json_object_update_existing(struct ast_json *object, struct ast_json *ot
  *
  * \param object JSON object to modify.
  * \param other JSON object to copy into \a object.
- * \return 0 on success.
- * \return -1 on error.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_update_missing(struct ast_json *object, struct ast_json *other);
 
@@ -683,8 +690,8 @@ struct ast_json_iter;
  *
  * \param object JSON object.
  * \return Iterator to the first field in \a object.
- * \return \c NULL \a object is empty.
- * \return \c NULL on error.
+ * \retval NULL \a object is empty.
+ *              on error.
  */
 struct ast_json_iter *ast_json_object_iter(struct ast_json *object);
 
@@ -697,8 +704,8 @@ struct ast_json_iter *ast_json_object_iter(struct ast_json *object);
  * \param object JSON object to iterate.
  * \param key Key of field to lookup.
  * \return Iterator pointing to the field with the given \a key.
- * \return \c NULL if \a key does not exist.
- * \return \c NULL on error.
+ * \retval NULL if \a key does not exist.
+ *              on error.
  */
 struct ast_json_iter *ast_json_object_iter_at(struct ast_json *object, const char *key);
 
@@ -708,7 +715,7 @@ struct ast_json_iter *ast_json_object_iter_at(struct ast_json *object, const cha
  * \param object JSON object \a iter was obtained from.
  * \param iter JSON object iterator.
  * \return Iterator to next field in \a object.
- * \return \c NULL if \a iter was the last field.
+ * \retval NULL if \a iter was the last field.
  */
 struct ast_json_iter *ast_json_object_iter_next(struct ast_json *object, struct ast_json_iter *iter);
 
@@ -736,14 +743,14 @@ struct ast_json *ast_json_object_iter_value(struct ast_json_iter *iter);
  * \brief Set the value of the field pointed to by an iterator.
  * \since 12.0.0
  *
- * \note The object steals the \a value reference even if it returns error;
+ * \note The object steals the \p value reference even if it returns error;
  * use ast_json_ref() to safely keep a pointer to it.
  *
- * \param object JSON object \a iter was obtained from.
+ * \param object JSON object \p iter was obtained from.
  * \param iter JSON object iterator.
- * \param value JSON value to store in \iter's field.
- * \return 0 on success.
- * \return -1 on error.
+ * \param value JSON value to store in \p iter's field.
+ * \retval 0 on success.
+ * \retval -1 on error.
  */
 int ast_json_object_iter_set(struct ast_json *object, struct ast_json_iter *iter, struct ast_json *value);
 
@@ -771,7 +778,7 @@ enum ast_json_encoding_format
  *
  * \param root JSON value.
  * \return String encoding of \a root.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 #define ast_json_dump_string(root) ast_json_dump_string_format(root, AST_JSON_COMPACT)
 
@@ -784,7 +791,7 @@ enum ast_json_encoding_format
  * \param root JSON value.
  * \param format encoding format type.
  * \return String encoding of \a root.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 char *ast_json_dump_string_format(struct ast_json *root, enum ast_json_encoding_format format);
 
@@ -799,8 +806,8 @@ char *ast_json_dump_string_format(struct ast_json *root, enum ast_json_encoding_
  * \param root JSON value.
  * \param dst \ref ast_str to store JSON encoding.
  * \param format encoding format type.
- * \return 0 on success.
- * \return -1 on error. The contents of \a dst are undefined.
+ * \retval 0 on success.
+ * \retval -1 on error. The contents of \a dst are undefined.
  */
 int ast_json_dump_str_format(struct ast_json *root, struct ast_str **dst, enum ast_json_encoding_format format);
 
@@ -813,8 +820,8 @@ int ast_json_dump_str_format(struct ast_json *root, struct ast_str **dst, enum a
  * \param root JSON value.
  * \param output File to write JSON encoding to.
  * \param format encoding format type.
- * \return 0 on success.
- * \return -1 on error. The contents of \a output are undefined.
+ * \retval 0 on success.
+ * \retval -1 on error. The contents of \a output are undefined.
  */
 int ast_json_dump_file_format(struct ast_json *root, FILE *output, enum ast_json_encoding_format format);
 
@@ -827,8 +834,8 @@ int ast_json_dump_file_format(struct ast_json *root, FILE *output, enum ast_json
  * \param root JSON value.
  * \param path Path to file to write JSON encoding to.
  * \param format encoding format type.
- * \return 0 on success.
- * \return -1 on error. The contents of \a output are undefined.
+ * \retval 0 on success.
+ * \retval -1 on error. The contents of \a output are undefined.
  */
 int ast_json_dump_new_file_format(struct ast_json *root, const char *path, enum ast_json_encoding_format format);
 
@@ -848,7 +855,7 @@ struct ast_json_error {
 	int position;
 	/*! Error message */
 	char text[AST_JSON_ERROR_TEXT_LENGTH];
-	/*! Source of the error (filename or <string>) */
+	/*! Source of the error (filename or \<string\>) */
 	char source[AST_JSON_ERROR_TEXT_LENGTH];
 };
 
@@ -858,7 +865,7 @@ struct ast_json_error {
  * \param input String to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_string(const char *input, struct ast_json_error *error);
 
@@ -868,7 +875,7 @@ struct ast_json *ast_json_load_string(const char *input, struct ast_json_error *
  * \param input \ref ast_str to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_str(const struct ast_str *input, struct ast_json_error *error);
 
@@ -879,7 +886,7 @@ struct ast_json *ast_json_load_str(const struct ast_str *input, struct ast_json_
  * \param buflen Length of \a buffer.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_buf(const char *buffer, size_t buflen, struct ast_json_error *error);
 
@@ -889,7 +896,7 @@ struct ast_json *ast_json_load_buf(const char *buffer, size_t buflen, struct ast
  * \param input \c FILE to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_file(FILE *input, struct ast_json_error *error);
 
@@ -899,7 +906,7 @@ struct ast_json *ast_json_load_file(FILE *input, struct ast_json_error *error);
  * \param path Path of file to parse.
  * \param[out] error Filled with information on error.
  * \return Parsed JSON element.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_load_new_file(const char *path, struct ast_json_error *error);
 
@@ -907,7 +914,7 @@ struct ast_json *ast_json_load_new_file(const char *path, struct ast_json_error
  * \brief Helper for creating complex JSON values.
  * \since 12.0.0
  *
- * See original Jansson docs at http://www.digip.org/jansson/doc/2.4/apiref.html#apiref-pack
+ * See original Jansson docs at http://www.digip.org/jansson/doc/2.11/apiref.html#apiref-pack
  * for more details.
  */
 struct ast_json *ast_json_pack(char const *format, ...);
@@ -916,7 +923,7 @@ struct ast_json *ast_json_pack(char const *format, ...);
  * \brief Helper for creating complex JSON values simply.
  * \since 12.0.0
  *
- * See original Jansson docs at http://www.digip.org/jansson/doc/2.4/apiref.html#apiref-pack
+ * See original Jansson docs at http://www.digip.org/jansson/doc/2.11/apiref.html#apiref-pack
  * for more details.
  */
 struct ast_json *ast_json_vpack(char const *format, va_list ap);
@@ -933,8 +940,8 @@ struct ast_json *ast_json_vpack(char const *format, va_list ap);
  *
  * \param lhs Value to compare.
  * \param rhs Other value to compare.
- * \return True (non-zero) if \a lhs and \a rhs are equal.
- * \return False (zero) if they are not.
+ * \retval True (non-zero) if \a lhs and \a rhs are equal.
+ * \retval False (zero) if they are not.
  */
 int ast_json_equal(const struct ast_json *lhs, const struct ast_json *rhs);
 
@@ -946,7 +953,7 @@ int ast_json_equal(const struct ast_json *lhs, const struct ast_json *rhs);
  *
  * \param value JSON value to copy.
  * \return Shallow copy of \a value.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_copy(const struct ast_json *value);
 
@@ -958,7 +965,7 @@ struct ast_json *ast_json_copy(const struct ast_json *value);
  *
  * \param value JSON value to copy.
  * \return Deep copy of \a value.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_deep_copy(const struct ast_json *value);
 
@@ -974,8 +981,8 @@ struct ast_json *ast_json_deep_copy(const struct ast_json *value);
  * \brief Simple name/number pair.
  * \param name Name
  * \param number Number
- * \return NULL if error (non-UTF8 characters, NULL inputs, etc.)
  * \return JSON object with name and number fields
+ * \retval NULL on error (non-UTF8 characters, NULL inputs, etc.)
  */
 struct ast_json *ast_json_name_number(const char *name, const char *number);
 
@@ -989,7 +996,7 @@ struct ast_json *ast_json_name_number(const char *name, const char *number);
  * \param tv \c timeval to encode.
  * \param zone Text string of a standard system zoneinfo file.  If NULL, the system localtime will be used.
  * \return JSON string with ISO 8601 formatted date/time.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_timeval(const struct timeval tv, const char *zone);
 
@@ -1001,10 +1008,26 @@ struct ast_json *ast_json_timeval(const struct timeval tv, const char *zone);
  * \param addr ast_sockaddr to encode
  * \param transport_type ast_transport to include in the address string if any. Should just be one.
  * \return JSON string containing the IP address with optional transport information
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 struct ast_json *ast_json_ipaddr(const struct ast_sockaddr *addr, enum ast_transport transport_type);
 
+/*!
+ * \brief Construct a context/exten/priority/application/application_data as JSON.
+ *
+ * If a \c NULL is passed for \c context or \c exten or \c app_name or \c app_data,
+ * or -1 for \c priority, the fields is set to ast_json_null().
+ *
+ * \param context Context name.
+ * \param exten Extension.
+ * \param priority Dialplan priority.
+ * \param app_name Application name.
+ * \param app_data Application argument.
+ * \return JSON object with \c context, \c exten and \c priority \c app_name \c app_data fields
+ */
+struct ast_json *ast_json_dialplan_cep_app(
+		const char *context, const char *exten, int priority, const char *app_name, const char *app_data);
+
 /*!
  * \brief Construct a context/exten/priority as JSON.
  *
@@ -1028,8 +1051,8 @@ struct ast_json_payload {
  *
  * \param json the ast_json blob we are loading
  *
+ * \return pointer to the ast_json_payload created
  * \retval NULL if we fail to alloc it
- * \retval pointer to the ast_json_payload created
  */
 struct ast_json_payload *ast_json_payload_create(struct ast_json *json);
 
@@ -1076,6 +1099,18 @@ enum ast_json_to_ast_vars_code {
  */
 enum ast_json_to_ast_vars_code ast_json_to_ast_variables(struct ast_json *json_variables, struct ast_variable **variables);
 
+struct varshead;
+
+/*!
+ * \brief Construct a JSON object from a \c ast_var_t list
+ * \since 14.2.0
+ *
+ * \param channelvars The list of \c ast_var_t to represent as JSON
+ *
+ * \return JSON object with variable names as keys and variable values as values
+ */
+struct ast_json *ast_json_channel_vars(struct varshead *channelvars);
+
 /*!@}*/
 
 #endif /* _ASTERISK_JSON_H */
