@@ -1,7 +1,7 @@
 /*
  * Asterisk -- An open source telephony toolkit.
  *
- * Copyright (C) 2009, Digium, Inc.
+ * Copyright (C) 2012, Digium, Inc.
  *
  * Russell Bryant <russell@digium.com>
  *
@@ -28,6 +28,7 @@
 #define __AST_SECURITY_EVENTS_DEFS_H__
 
 #include "asterisk/network.h"
+#include "asterisk/netsock2.h"
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -35,11 +36,6 @@ extern "C" {
 
 /*!
  * \brief Security event types
- *
- * AST_EVENT_SECURITY is the event type of an ast_event generated as a security
- * event.  The event will have an information element of type
- * AST_EVENT_IE_SECURITY_EVENT which identifies the security event sub-type.
- * This enum defines the possible values for this sub-type.
  */
 enum ast_security_event_type {
 	/*!
@@ -140,20 +136,11 @@ enum ast_security_event_severity {
 	AST_SECURITY_EVENT_SEVERITY_ERROR = (1 << 1),
 };
 
-/*!
- * \brief Transport types
- */
-enum ast_security_event_transport_type {
-	AST_SECURITY_EVENT_TRANSPORT_UDP,
-	AST_SECURITY_EVENT_TRANSPORT_TCP,
-	AST_SECURITY_EVENT_TRANSPORT_TLS,
-};
-
 #define AST_SEC_EVT(e) ((struct ast_security_event_common *) e)
 
-struct ast_security_event_ipv4_addr {
-	const struct sockaddr_in *sin;
-	enum ast_security_event_transport_type transport;
+struct ast_security_event_ip_addr {
+	const struct ast_sockaddr *addr;
+	enum ast_transport transport;
 };
 
 /*!
@@ -202,12 +189,12 @@ struct ast_security_event_common {
 	 * \brief Local address the request came in on
 	 * \note Always required
 	 */
-	struct ast_security_event_ipv4_addr local_addr;
+	struct ast_security_event_ip_addr local_addr;
 	/*!
 	 * \brief Remote address the request came from
 	 * \note Always required
 	 */
-	struct ast_security_event_ipv4_addr remote_addr;
+	struct ast_security_event_ip_addr remote_addr;
 };
 
 /*!
@@ -407,7 +394,7 @@ struct ast_security_event_successful_auth {
 	 * \brief Using password - if a password was used or not
 	 * \note required, 0 = no, 1 = yes
 	 */
-	uint32_t *using_password;
+	uint32_t using_password;
 };
 
 /*!
@@ -418,7 +405,7 @@ struct ast_security_event_unexpected_addr {
 	 * \brief Event descriptor version
 	 * \note This _must_ be changed if this event descriptor is changed.
 	 */
-	#define AST_SECURITY_EVENT_UNEXPECTED_ADDR_VERSION 1
+	#define AST_SECURITY_EVENT_UNEXPECTED_ADDR_VERSION 2
 	/*!
 	 * \brief Common security event descriptor elements
 	 * \note Account ID required
@@ -428,7 +415,7 @@ struct ast_security_event_unexpected_addr {
 	 * \brief Expected remote address
 	 * \note required
 	 */
-	struct ast_security_event_ipv4_addr expected_addr;
+	struct ast_security_event_ip_addr expected_addr;
 };
 
 /*!
