@@ -239,6 +239,19 @@ int ast_base64encode_full(char *dst, const unsigned char *src, int srclen, int m
  */
 int ast_base64encode(char *dst, const unsigned char *src, int srclen, int max);
 
+/*!
+ * \brief Same as ast_base64encode, but does hte math for you and returns
+ * an encoded string
+ *
+ * \note The returned string will need to be freed later
+ *
+ * \param src The source buffer
+ *
+ * \retval NULL on failure
+ * \return Encoded string on success
+ */
+char *ast_base64encode_string(const char *src);
+
 /*!
  * \brief Decode data from base64
  * \param dst the destination buffer
@@ -250,6 +263,99 @@ int ast_base64encode(char *dst, const unsigned char *src, int srclen, int max);
  */
 int ast_base64decode(unsigned char *dst, const char *src, int max);
 
+/*!
+ * \brief Same as ast_base64decode, but does the math for you and returns
+ * a decoded string
+ *
+ * \note The returned string will need to be freed later and IS NULL terminated
+ *
+ * \param src The source buffer
+ *
+ * \retval NULL on failure
+ * \return Decoded string on success
+ */
+char *ast_base64decode_string(const char *src);
+
+/*!
+ * \brief Decode data from base64 URL
+ *
+ * \param dst The destination buffer
+ * \param src The source buffer
+ * \param max The maximum number of bytes to write into the destination
+ *            buffer. Note that this function will not ensure that the
+ *            destination buffer is NULL terminated. So, in general,
+ *            this parameter should be sizeof(dst) - 1
+ */
+int ast_base64url_decode(unsigned char *dst, const char *src, int max);
+
+/*!
+ * \brief Same as ast_base64encode_full but for base64 URL
+ *
+ * \param dst The destination buffer
+ * \param src The source buffer
+ * \param srclen The number of bytes present in the source buffer
+ * \param max The maximum number of bytes to write into the destination
+ *            buffer, *including* the terminating NULL character.
+ * \param linebreaks Set to 1 if there should be linebreaks inserted
+ *                   in the result
+ */
+int ast_base64url_encode_full(char *dst, const unsigned char *src, int srclen, int max, int linebreaks);
+
+/*!
+ * \brief Encode data in base64 URL
+ *
+ * \param dst The destination buffer
+ * \param src The source data to be encoded
+ * \param srclen The number of bytes present in the source buffer
+ * \param max The maximum number of bytes to write into the destination
+ *            buffer, including the terminating NULL character
+ */
+int ast_base64url_encode(char *dst, const unsigned char *src, int srclen, int max);
+
+/*!
+ * \brief Decode string from base64 URL
+ *
+ * \note The returned string will need to be freed later
+ *
+ * \param src The source buffer
+ *
+ * \retval NULL on failure
+ * \return Decoded string on success
+ */
+char *ast_base64url_decode_string(const char *src);
+
+/*!
+ * \brief Encode string in base64 URL
+ *
+ * \note The returned string will need to be freed later
+ *
+ * \param src The source data to be encoded
+ *
+ * \retval NULL on failure
+ * \return Encoded string on success
+ */
+char *ast_base64url_encode_string(const char *src);
+
+/*!
+ * \brief Performs a base 64 encode algorithm on the contents of a File
+ * \param inputfile A FILE handle to the input file to be encoded. Must be readable. This handle is not automatically closed.
+ * \param outputfile A FILE handle to the output file to receive the base 64 encoded contents of the input file, identified by filename.
+ * \param endl The line ending to use (e.g. either "\n" or "\r\n")
+ *
+ * \return zero on success, -1 on error.
+ */
+int ast_base64_encode_file(FILE *inputfile, FILE *outputfile, const char *endl);
+
+/*!
+ * \brief Performs a base 64 encode algorithm on the contents of a File
+ * \param filename The path to the file to be encoded. Must be readable, file is opened in read mode.
+ * \param outputfile A FILE handle to the output file to receive the base 64 encoded contents of the input file, identified by filename.
+ * \param endl The line ending to use (e.g. either "\n" or "\r\n")
+ *
+ * \return zero on success, -1 on error.
+ */
+int ast_base64_encode_file_path(const char *filename, FILE *outputfile, const char *endl);
+
 #define AST_URI_ALPHANUM     (1 << 0)
 #define AST_URI_MARK         (1 << 1)
 #define AST_URI_UNRESERVED   (AST_URI_ALPHANUM | AST_URI_MARK)
@@ -299,8 +405,8 @@ void ast_uri_decode(char *s, struct ast_flags spec);
 	\param string String to be converted
 	\param outbuf Resulting encoded string
 	\param buflen Size of output buffer
-	\return 0 for success
-	\return -1 if buflen is too short.
+	\retval 0 for success
+	\retval -1 if buflen is too short.
  */
 int ast_xml_escape(const char *string, char *outbuf, size_t buflen);
 
@@ -375,11 +481,35 @@ static force_inline void ast_slinear_saturated_multiply(short *input, short *val
 		*input = (short) res;
 }
 
+static force_inline void ast_slinear_saturated_multiply_float(short *input, float *value)
+{
+	float res;
+
+	res = (float) *input * *value;
+	if (res > 32767)
+		*input = 32767;
+	else if (res < -32768)
+		*input = -32768;
+	else
+		*input = (short) res;
+}
+
 static force_inline void ast_slinear_saturated_divide(short *input, short *value)
 {
 	*input /= *value;
 }
 
+static force_inline void ast_slinear_saturated_divide_float(short *input, float *value)
+{
+	float res = (float) *input / *value;
+	if (res > 32767)
+		*input = 32767;
+	else if (res < -32768)
+		*input = -32768;
+	else
+		*input = (short) res;
+}
+
 #ifdef localtime_r
 #undef localtime_r
 #endif
@@ -423,8 +553,13 @@ int ast_careful_fwrite(FILE *f, int fd, const char *s, size_t len, int timeoutms
  * Thread management support (should be moved to lock.h or a different header)
  */
 
-#define AST_STACKSIZE     (((sizeof(void *) * 8 * 8) - 16) * 1024)
-#define AST_STACKSIZE_LOW (((sizeof(void *) * 8 * 2) - 16) * 1024)
+#if defined(PTHREAD_STACK_MIN)
+# define AST_STACKSIZE     MAX((((sizeof(void *) * 8 * 8) - 16) * 1024), PTHREAD_STACK_MIN)
+# define AST_STACKSIZE_LOW MAX((((sizeof(void *) * 8 * 2) - 16) * 1024), PTHREAD_STACK_MIN)
+#else
+# define AST_STACKSIZE     (((sizeof(void *) * 8 * 8) - 16) * 1024)
+# define AST_STACKSIZE_LOW (((sizeof(void *) * 8 * 2) - 16) * 1024)
+#endif
 
 int ast_background_stacksize(void);
 
@@ -486,7 +621,6 @@ long int ast_random(void);
 /*!
  * \brief Disable PMTU discovery on a socket
  * \param sock The socket to manipulate
- * \return Nothing
  *
  * On Linux, UDP sockets default to sending packets with the Dont Fragment (DF)
  * bit set. This is supposedly done to allow the application to do PMTU
@@ -502,7 +636,8 @@ void ast_enable_packet_fragmentation(int sock);
  * \brief Recursively create directory path
  * \param path The directory path to create
  * \param mode The permissions with which to try to create the directory
- * \return 0 on success or an error code otherwise
+ * \retval 0 on success
+ * \return error code otherwise
  *
  * Creates a directory path, creating parent directories as needed.
  */
@@ -515,9 +650,11 @@ int ast_mkdir(const char *path, int mode);
  * If \a base_path does not exist, it will not be created and this function
  * returns \c EPERM.
  *
+ * \param base_path
  * \param path The directory path to create
  * \param mode The permissions with which to try to create the directory
- * \return 0 on success or an error code otherwise
+ * \retval 0 on success
+ * \return an error code otherwise
  */
 int ast_safe_mkdir(const char *base_path, const char *path, int mode);
 
@@ -529,7 +666,8 @@ int ast_safe_mkdir(const char *base_path, const char *path, int mode);
  * \param v the value to check
  * \param min minimum lower bound (inclusive)
  * \param max maximum upper bound (inclusive)
- * \return 0 if value out of bounds, otherwise true (non-zero)
+ * \retval 0 if value out of bounds
+ * \retval non-zero otherwise
  */
 #define IN_BOUNDS(v, min, max) ((v) >= (min)) && ((v) <= (max))
 
@@ -538,7 +676,8 @@ int ast_safe_mkdir(const char *base_path, const char *path, int mode);
  *
  * \param v the value to check
  * \param a the array to bound check
- * \return 0 if value out of bounds, otherwise true (non-zero)
+ * \retval 0 if value out of bounds
+ * \retval non-zero otherwise
  */
 #define ARRAY_IN_BOUNDS(v, a) IN_BOUNDS((int) (v), 0, ARRAY_LEN(a) - 1)
 
@@ -560,7 +699,7 @@ struct ast_http_digest {
 
 /*!
  * \brief Parse digest authorization header.
- * \return Returns -1 if we have no auth or something wrong with digest.
+ * \return -1 if we have no auth or something wrong with digest.
  * \note This function may be used for Digest request and responce header.
  * request arg is set to nonzero, if we parse Digest Request.
  * pedantic arg can be set to nonzero if we need to do addition Digest check.
@@ -605,8 +744,6 @@ static void force_inline _ast_assert(int condition, const char *condition_str, c
  * \brief Force a crash if DO_CRASH is defined.
  *
  * \note If DO_CRASH is not defined then the function returns.
- *
- * \return Nothing
  */
 void DO_CRASH_NORETURN ast_do_crash(void);
 
@@ -698,7 +835,8 @@ char *ast_eid_to_str(char *s, int maxlen, struct ast_eid *eid);
  * This function expects an EID in the format:
  *    00:11:22:33:44:55
  *
- * \return 0 success, non-zero failure
+ * \retval 0 success
+ * \retval non-zero failure
  * \since 1.6.1
  */
 int ast_str_to_eid(struct ast_eid *eid, const char *s);
@@ -706,7 +844,8 @@ int ast_str_to_eid(struct ast_eid *eid, const char *s);
 /*!
  * \brief Compare two EIDs
  *
- * \return 0 if the two are the same, non-zero otherwise
+ * \retval 0 if the two are the same
+ * \retval non-zero otherwise
  * \since 1.6.1
  */
 int ast_eid_cmp(const struct ast_eid *eid1, const struct ast_eid *eid2);
@@ -714,7 +853,8 @@ int ast_eid_cmp(const struct ast_eid *eid1, const struct ast_eid *eid2);
 /*!
  * \brief Check if EID is empty
  *
- * \return 1 if the EID is empty, zero otherwise
+ * \retval 1 if the EID is empty
+ * \retval 0 otherwise
  * \since 13.12.0
  */
 int ast_eid_is_empty(const struct ast_eid *eid);
@@ -814,7 +954,7 @@ static inline void _raii_cleanup_block(_raii_cleanup_block_t *b) { (*b)(); }
  * \param key User's password to crypt.
  * \param salt Salt to crypt with.
  * \return Crypted password.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 char *ast_crypt(const char *key, const char *salt);
 
@@ -827,7 +967,7 @@ char *ast_crypt(const char *key, const char *salt);
  *
  * \param key User's password to crypt.
  * \return Crypted password.
- * \return \c NULL on error.
+ * \retval NULL on error.
  */
 char *ast_crypt_encrypt(const char *key);
 
@@ -836,8 +976,8 @@ char *ast_crypt_encrypt(const char *key);
  *
  * \param key User's password to validate.
  * \param expected Expected result from crypt.
- * \return True (non-zero) if \a key matches \a expected.
- * \return False (zero) if \a key doesn't match.
+ * \retval True (non-zero) if \a key matches \a expected.
+ * \retval False (zero) if \a key doesn't match.
  */
 int ast_crypt_validate(const char *key, const char *expected);
 
@@ -846,8 +986,8 @@ int ast_crypt_validate(const char *key, const char *expected);
  * \since 13.7.0
  *
  * \param filename File to test.
- * \return True (non-zero) if the file exists and is readable.
- * \return False (zero) if the file either doesn't exists or is not readable.
+ * \retval True (non-zero) if the file exists and is readable.
+ * \retval False (zero) if the file either doesn't exists or is not readable.
  */
 int ast_file_is_readable(const char *filename);
 
@@ -855,12 +995,12 @@ int ast_file_is_readable(const char *filename);
  * \brief Compare 2 major.minor.patch.extra version strings.
  * \since 13.7.0
  *
- * \param version1.
- * \param version2.
+ * \param version1
+ * \param version2
  *
- * \return <0 if version 1 < version 2.
- * \return =0 if version 1 = version 2.
- * \return >0 if version 1 > version 2.
+ * \retval negative if version 1 < version 2.
+ * \retval 0 if version 1 = version 2.
+ * \retval positive if version 1 > version 2.
  */
 int ast_compare_versions(const char *version1, const char *version2);
 
@@ -868,8 +1008,8 @@ int ast_compare_versions(const char *version1, const char *version2);
  * \brief Test that an OS supports IPv6 Networking.
  * \since 13.14.0
  *
- * \return True (non-zero) if the IPv6 supported.
- * \return False (zero) if the OS doesn't support IPv6.
+ * \retval True (non-zero) if the IPv6 supported.
+ * \retval False (zero) if the OS doesn't support IPv6.
  */
 int ast_check_ipv6(void);
 
@@ -888,8 +1028,8 @@ enum ast_fd_flag_operation {
  * \param fd File descriptor to set flags on
  * \param flags The flag(s) to set
  *
- * \return -1 on error
- * \return 0 if successful
+ * \retval -1 on error
+ * \retval 0 if successful
  */
 #define ast_fd_set_flags(fd, flags) \
 	__ast_fd_set_flags((fd), (flags), AST_FD_FLAG_SET, __FILE__, __LINE__, __PRETTY_FUNCTION__)
@@ -904,8 +1044,8 @@ enum ast_fd_flag_operation {
  * \param fd File descriptor to clear flags on
  * \param flags The flag(s) to clear
  *
- * \return -1 on error
- * \return 0 if successful
+ * \retval -1 on error
+ * \retval 0 if successful
  */
 #define ast_fd_clear_flags(fd, flags) \
 	__ast_fd_set_flags((fd), (flags), AST_FD_FLAG_CLEAR, __FILE__, __LINE__, __PRETTY_FUNCTION__)
@@ -952,17 +1092,27 @@ int ast_pipe_nonblock(int filedes[2]);
  *
  * \param is_user_interface Non-zero to mark the thread as a user interface.
  *
- * \return 0 if successfuly marked current thread.
- * \return Non-zero if marking current thread failed.
+ * \retval True (non-zero) if marking current thread failed.
+ * \retval False (zero) if successfuly marked current thread.
  */
 int ast_thread_user_interface_set(int is_user_interface);
 
 /*!
  * \brief Indicates whether the current thread is a user interface
  *
- * \return True (non-zero) if thread is a user interface.
- * \return False (zero) if thread is not a user interface.
+ * \retval True (non-zero) if thread is a user interface.
+ * \retval False (zero) if thread is not a user interface.
  */
 int ast_thread_is_user_interface(void);
 
+/*!
+ * \brief Test for the presence of an executable command in $PATH
+ *
+ * \param cmd Name of command to locate.
+ *
+ * \retval True (non-zero) if command is in $PATH.
+ * \retval False (zero) command not found.
+ */
+int ast_check_command_in_path(const char *cmd);
+
 #endif /* _ASTERISK_UTILS_H */
