@@ -35,6 +35,14 @@ enum ast_doc_src {
 #ifdef AST_XML_DOCS
 
 struct ao2_container;
+struct ast_xml_node;
+
+/*!
+ * \brief The struct to be used as the head of an ast_xml_doc_item list
+ *        when being manipulated
+ * \since 13.0.0
+ */
+AST_LIST_HEAD(ast_xml_doc_item_list, ast_xml_doc_item);
 
 /*! \brief Struct that contains the XML documentation for a particular item.  Note
  * that this is an ao2 ref counted object.
@@ -61,11 +69,27 @@ struct ast_xml_doc_item {
 		AST_STRING_FIELD(name);
 		/*! The type of the item */
 		AST_STRING_FIELD(type);
+		/*! Reference to another field */
+		AST_STRING_FIELD(ref);
 	);
+	/*! The node that this item was created from. Note that the life time of
+	 * the node is not tied to the lifetime of this object.
+	 */
+	struct ast_xml_node *node;
 	/*! The next XML documentation item that matches the same name/item type */
-	struct ast_xml_doc_item *next;
+	AST_LIST_ENTRY(ast_xml_doc_item) next;
 };
 
+/*! \brief Execute an XPath query on the loaded XML documentation
+ * \param fmt The XPath query string to execute
+ * \param ... Variable printf style format arguments
+ * \retval An XPath results object on success
+ * \retval NULL if no match found
+ *
+ * \since 12
+ */
+struct ast_xml_xpath_results *__attribute__((format(printf, 1, 2))) ast_xmldoc_query(const char *fmt, ...);
+
 /*!
  *  \brief Get the syntax for a specified application or function.
  *  \param type Application, Function or AGI ?
@@ -97,6 +121,34 @@ char *ast_xmldoc_build_seealso(const char *type, const char *name, const char *m
  */
 char *ast_xmldoc_build_arguments(const char *type, const char *name, const char *module);
 
+/*!
+ * \brief Generate the [final response] tag based on type of node ('application',
+ *        'function' or 'agi') and name.
+ *
+ * \param type 'application', 'function' or 'agi'
+ * \param name Name of the application or function to build the 'responses' tag.
+ * \param module The module the item is in (optional, can be NULL)
+ *
+ * \return An XMLDoc item list with the [final response] tag content.
+ *
+ * \since 13.0.0
+ */
+struct ast_xml_doc_item *ast_xmldoc_build_final_response(const char *type, const char *name, const char *module);
+
+/*!
+ * \brief Generate the [list responses] tag based on type of node ('application',
+ *        'function' or 'agi') and name.
+ *
+ * \param type 'application', 'function' or 'agi'
+ * \param name Name of the application or function to build the 'responses' tag.
+ * \param module The module the item is in (optional, can be NULL)
+ *
+ * \return An XMLDoc item list with the [list responses] tag content.
+ *
+ * \since 13.0.0
+ */
+struct ast_xml_doc_item *ast_xmldoc_build_list_responses(const char *type, const char *name, const char *module);
+
 /*!
  *  \brief Colorize and put delimiters (instead of tags) to the xmldoc output.
  *  \param bwinput Not colorized input with tags.
@@ -138,6 +190,17 @@ char *ast_xmldoc_build_description(const char *type, const char *name, const cha
  */
 struct ao2_container *ast_xmldoc_build_documentation(const char *type);
 
+/*!
+ *  \brief Regenerate the documentation for a particular item
+ *  \param item The documentation item to regenerate
+ *
+ *  \retval -1 on error
+ *  \retval 0 on success
+ *
+ *  \since 12
+ */
+int ast_xmldoc_regenerate_doc_item(struct ast_xml_doc_item *item);
+
 #endif /* AST_XML_DOCS */
 
 #endif /* _ASTERISK_XMLDOC_H */
